// Mugurel Ionut Andreica - Bucuresti
#include <stdio.h>
#include <vector>
#include <algorithm>

using namespace std;

#define NMAX 100100

#define min(a, b) ((a) <= (b) ? (a) : (b))
#define max(a, b) ((a) >= (b) ? (a) : (b))

struct kdtree_node {
	int xmin, xmax, ymin, ymax;
	int cnt;
	long long S;
	struct kdtree_node *left, *right, *parent;
};

vector<pair<int, int> > points;
int x[NMAX], y[NMAX];
long long ans[NMAX];
struct kdtree_node *root, *leaf[NMAX];
int N;

void read_input() {
	freopen("snpid.in", "r", stdin);
	scanf("%d", &N);
	for (int i = 0; i < N; i++) {
		x[i] = i + 1;
		scanf("%d", &y[i]);
		points.push_back(make_pair(i, i));
	}
}

void build_kdtree(struct kdtree_node *node, int level, vector<pair<int, int> >* points) {
	if (points->size() == 1) {
		node->cnt = 1;
		node->xmin = node->xmax = x[(*points)[0].second];
		node->ymin = node->ymax = y[(*points)[0].second];
		leaf[(*points)[0].second] = node;
		return;
	}
	
	vector<pair<int, int> > half1, half2;
	int i, mid = points->size() / 2;

	for (i = 0; i < mid; i++)
		if (level == 0)
			half1.push_back(make_pair(y[(*points)[i].second], (*points)[i].second));
		else
			half1.push_back(make_pair(x[(*points)[i].second], (*points)[i].second));

	for (i = mid; i < points->size(); i++)
		if (level == 0)
			half2.push_back(make_pair(y[(*points)[i].second], (*points)[i].second));
		else
			half2.push_back(make_pair(x[(*points)[i].second], (*points)[i].second));

	points->clear();
	sort(half1.begin(), half1.end());
	sort(half2.begin(), half2.end());

	node->left = new struct kdtree_node;
	node->left->S = 0;
	node->left->left = node->left->right = NULL;
	node->left->parent = node;
	build_kdtree(node->left, 1 - level, &half1);

	node->right = new struct kdtree_node;
	node->right->S = 0;
	node->right->left = node->right->right = NULL;
	node->right->parent = node;
	build_kdtree(node->right, 1 - level, &half2);

	node->cnt = node->left->cnt + node->right->cnt;
	node->xmin = min(node->left->xmin, node->right->xmin);
	node->xmax = max(node->left->xmax, node->right->xmax);
	node->ymin = min(node->left->ymin, node->right->ymin);
	node->ymax = max(node->left->ymax, node->right->ymax);
}

int xmin, ymin, xmax, ymax, cnt;

int queryCnt(struct kdtree_node *node) {
	if (node->xmax < xmin || node->xmin > xmax || node->ymax < ymin || node->ymin > ymax)
		return 0;
	if (xmin <= node->xmin && node->xmax <= xmax && ymin <= node->ymin && node->ymax <= ymax)
		return node->cnt;
	return queryCnt(node->left) + queryCnt(node->right);
}

void updateS(struct kdtree_node *node) {
	if (node->xmax < xmin || node->xmin > xmax || node->ymax < ymin || node->ymin > ymax)
		return;
	if (xmin <= node->xmin && node->xmax <= xmax && ymin <= node->ymin && node->ymax <= ymax) {
		node->S += cnt;
		return;
	}
	updateS(node->left);
	updateS(node->right);
}

void compute() {
	int i;

	for (i = 0; i < N; i++) {
		xmin = x[i] + 1; xmax = N; ymin = y[i] + 1; ymax = N;
		cnt = queryCnt(root);

		xmin = 1; xmax = x[i] - 1; ymin = 1; ymax = y[i] - 1;
		updateS(root);
	}
	
	for (i = 0; i < N; i++) {
		ans[i] = 0;
		struct kdtree_node *node = leaf[i];
		while (node != NULL) {
			ans[i] += node->S;
			node = node->parent;
		}
	}
}

void write_output() {
	freopen("snpid.out", "w", stdout);
	for (int i = 0; i < N; i++)
		printf("%lld\n", ans[i]);
}

int main() {
	read_input();

	root = new struct kdtree_node;
	root->left = root->right = root->parent = NULL;
	root->cnt = 0;
	root->S = 0;
	build_kdtree(root, 0, &points);

	compute();
	write_output();
	return 0;
}
