// Mugurel Ionut Andreica - Bucuresti

#include <stdio.h>
#include <string.h>
#include <set>
#include <vector>
#include <algorithm>

using namespace std;

#define NMAX 100100
#define SOLUTION_4

#define FILEIN "snpid.in"
#define FILEOUT "snpid.out"

int y[NMAX];
int N;
long long ans[NMAX];

void read_input() {
	freopen(FILEIN, "r", stdin);
	scanf("%d", &N);
	for (int i = 1; i <= N; i++)
		scanf("%d", &y[i]);
}

#ifdef SOLUTION_1
// Solution 1 : O(N^3)
void solution_1() {
	int i, j, k;
	for (i = 1; i <= N; i++) {
		ans[i] = 0;
		for (j = i + 2; j <= N; j++)
			if (y[j] > y[i])
				for (k = i + 1; k < j; k++)
					if (y[i] < y[k] && y[k] < y[j])
						ans[i]++;
	}
}
#endif

#ifdef SOLUTION_2
// Solution 2 : O(N^2 * log(N))

#define NODEMAX 131072
int nra[2 * NODEMAX];

int query(int a) {
	int ans = 0, node = NODEMAX + a - 1;
	while (node > 1) {
		if ((node & 1) > 0) // node is the right son of its parent.
			ans += nra[node - 1]; // node - 1 is the left son of node's parent.		
		node = node >> 1;
	}
	return ans;
}

void update(int a) {
	int node = NODEMAX + a - 1;
	while (node >= 1) {
		nra[node]++;
		node = node >> 1;
	}
}

void solution_2() {
	for (int i = 1; i <= N; i++) {
		//fprintf(stderr, "i=%d\n", i);
		memset(nra, 0, sizeof(nra));
		ans[i] = 0;
		
		for (int j = i + 1; j <= N; j++) {
			//fprintf(stderr, "j=%d\n", j);
			if (y[j] > y[i]) {
				ans[i] += query(y[j]);
				update(y[j]);
			}
		}
	}
}
#endif

#ifdef SOLUTION_3
// Solution 3 : O(N^2 * log(N))

#define NODEMAX 131072
int nra[2 * NODEMAX];
set<pair<int, int> > points;
vector<int> jpositions;

int query(int a) {
	int ans = 0, node = NODEMAX + a - 1;
	while (node > 1) {
		if ((node & 1) > 0) // node is the right son of its parent.
			ans += nra[node - 1]; // node - 1 is the left son of node's parent.		
		node = node >> 1;
	}
	return ans;
}

void update(int a) {
	int node = NODEMAX + a - 1;
	while (node >= 1) {
		nra[node]++;
		node = node >> 1;
	}
}

void solution_3() {
	set<pair<int, int> >::iterator it, it2;
	
	for (int i = N; i >= 1; i--) {
		//fprintf(stderr, "i=%d\n", i);
		memset(nra, 0, sizeof(nra));
		ans[i] = 0;

		jpositions.clear();
		for (it = points.lower_bound(make_pair(y[i], -1)); it != points.end(); it++) {
			jpositions.push_back(it->second);
		}
		
		sort(jpositions.begin(), jpositions.end());
		for (int k = 0; k < jpositions.size(); k++) {
			int j = jpositions[k];
			//fprintf(stderr, "j=%d\n", j);
			ans[i] += query(y[j]);
			update(y[j]);
		}
		
		points.insert(make_pair(y[i], i));
	}
}
#endif

#ifdef SOLUTION_4
// Solution 4 : O(N*log(N))

#define NODEMAX 131072
int nractive[2 * NODEMAX];
long long vstart[2 * NODEMAX];
long long step[2 * NODEMAX];
long long nrinv[NODEMAX];

int queryCnt(int a) {
	int ans = 0, node = NODEMAX + a - 1;
	while (node > 1) {
		if ((node & 1) == 0) // node is the left son of its parent.
			ans += nractive[node + 1]; // node + 1 is the right son of node's parent.		
		node = node >> 1;
	}
	return ans;
}

long long queryInv(int a) {
	long long ans = 0;
	int	node = NODEMAX + a - 1, rank = 0;
	while (node >= 1) {
		//if (step[node] > 0 || vstart[node] > 0) {
		//	fprintf(stderr, "queryInv: y=%d, node=%d, vstart[node]=%lld, step[node]=%lld, rank=%d\n", a, node, vstart[node], step[node], rank);
		//}
		
		ans += (vstart[node] - step[node] * rank);

		if ((node & 1) > 0) { // node is the right son of its parent.
			rank += nractive[node - 1]; // node - 1 is the left son of node's parent.		
		}
		node = node >> 1;
	}
	return ans + nrinv[a];
}

#define AMAX 25
int ancestors[AMAX];

void updateCnt(int a) {
	int node = NODEMAX + a - 1, nranc = 0, i;
	
	nrinv[a] = queryInv(a);

	while (node >= 1) {
		ancestors[nranc] = node;
		nranc++;
		node = node >> 1;
	}

	long long vstartcumulated = 0, stepcumulated = 0;

	for (i = nranc - 1; i >= 1; i--) {
		int left_son = ancestors[i] << 1;
		int right_son = left_son + 1;

		vstartcumulated += vstart[ancestors[i]];
		stepcumulated += step[ancestors[i]];
		vstart[ancestors[i]] = step[ancestors[i]] = 0;

		//if (stepcumulated > 0) {
		//	fprintf(stderr, "-updateCnt node=%d accumulating vstartcumulated=%lld, stepcumulated=%lld\n", ancestors[i], vstartcumulated, stepcumulated);
		//}
		
		if (ancestors[i - 1] == right_son) {
			vstart[left_son] += vstartcumulated;
			step[left_son] += stepcumulated;
			vstartcumulated -= stepcumulated * nractive[left_son];
			//if (stepcumulated > 0 && nractive[left_son] > 0) {
			//	fprintf(stderr, "--updateCnt pushing to left_son=%d, vstart[left_son]=%lld, step[left_son]=%lld, nractive[left_son]=%d\n", left_son, vstart[left_son], step[left_son], nractive[left_son]);
			//	fprintf(stderr, "--updateCnt newly accumulated: vstartcumulated=%lld, stepcumulated=%lld\n", vstartcumulated, stepcumulated);
			//}
		} else {
			vstart[right_son] += vstartcumulated - stepcumulated * nractive[left_son];
			step[right_son] += stepcumulated;
		
			//if (stepcumulated > 0 && nractive[right_son] > 0) {
			//	fprintf(stderr, "--updateCnt pushing to right_son=%d, vstart[right_son]=%lld, step[right_son]=%lld, nractive[right_son]=%d\n", right_son, vstart[right_son], step[right_son], nractive[right_son]);
			//	fprintf(stderr, "--updateCnt newly accumulated: vstartcumulated=%lld, stepcumulated=%lld\n", vstartcumulated, stepcumulated);
			//}
		}
	}

	for (i = 0; i < nranc; i++)
		nractive[ancestors[i]]++;

	vstart[ancestors[0]] = step[ancestors[0]] = 0;
}

void updateInv(int v, int a) {
	int node = NODEMAX + a - 1;
	int last_rank = v - 1;

	// Update the coordinates [1,a].
	while (1) {
		while (((node & 1) > 0) && (node > 1)) {
			node = node >> 1;
		}

		last_rank -= nractive[node];
		vstart[node] += v - (last_rank + 1);
		step[node]++;

		if (node == 1)
			break;
		
		while ((node & 1) == 0) {
			node = node >> 1;
		}
		
		if (node == 1)
			break;
		node = node - 1;
	}
}

void solution_4() {
	int P, Q;
	long long invP;
	
	for (int i = N; i >= 1; i--) {
		//fprintf(stderr, "## i=%d, y[i]=%d\n", i, y[i]);

		P = queryCnt(y[i]);
		Q = N - i - P;

		//fprintf(stderr, "P=%d, Q=%d\n", P, Q);

		if (P > 0) {
			invP = queryInv(y[i] + 1);
		} else {
			invP = 0;
		}
		
		//fprintf(stderr, "invP=%lld\n", invP);
		ans[i] = (long long) (P - 1) * (long long) (P) / 2 - invP;

		if (Q > 0)
			updateInv(Q, y[i] - 1);

		updateCnt(y[i]);
	}
}

#endif

void compute() {
	#ifdef SOLUTION_1
	fprintf(stderr, "SOLUTION_1\n");
	solution_1();
	#endif
	
	#ifdef SOLUTION_2
	fprintf(stderr, "SOLUTION_2\n");
	solution_2();
	#endif

	#ifdef SOLUTION_3
	fprintf(stderr, "SOLUTION_3\n");
	solution_3();
	#endif

	#ifdef SOLUTION_4
	fprintf(stderr, "SOLUTION_4\n");
	solution_4();
	#endif
}

void write_output() {
	freopen(FILEOUT, "w", stdout);
	for (int i = 1; i <= N; i++)
		printf("%lld\n", ans[i]);
}

int main() {
	//freopen("log.txt", "w", stderr);
	read_input();
	compute();
	write_output();
	return 0;
}
